"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
require("../_tools/before-test");
const path = tslib_1.__importStar(require("path"));
const optimize_1 = tslib_1.__importDefault(require("../../backend/optimize"));
const file_utils_1 = require("../../common/file-utils");
const image_diff_1 = require("../_tools/image-diff");
const constants_1 = require("../../common/constants");
const relPath = (file) => path.resolve(__dirname, file);
const png = '../_files/600_600.png';
const jpg = '../_files/fox.jpg';
test('optimize png success', async () => {
    const files = await file_utils_1.saveFilesTmp([relPath(png)]);
    const file = files[0];
    const optimized = await optimize_1.default(file, {
        exportExt: constants_1.SupportedExt.png,
    });
    const diffResult = await image_diff_1.fullDiff({
        actualImage: file_utils_1.getFilePath(optimized),
        expectedImage: file_utils_1.getFilePath(file),
    });
    expect(diffResult.percentage).toBeLessThan(0.01);
});
test('optimize png fail', async () => {
    const image = {
        id: '404',
        url: '/',
        size: 0,
        ext: constants_1.SupportedExt.png,
        originalName: '',
    };
    try {
        await optimize_1.default(image, {
            exportExt: constants_1.SupportedExt.png,
        });
    }
    catch (e) {
        expect(e).toBeTruthy();
    }
});
test('optimize jpg success', async () => {
    const files = await file_utils_1.saveFilesTmp([relPath(jpg)]);
    const file = files[0];
    const optimized = await optimize_1.default(file, {
        exportExt: constants_1.SupportedExt.jpg,
    });
    const diffResult = await image_diff_1.fullDiff({
        actualImage: file_utils_1.getFilePath(optimized),
        expectedImage: file_utils_1.getFilePath(file),
    });
    expect(diffResult.percentage).toBeLessThan(0.1);
});
test('optimize jpg fail', async () => {
    const image = {
        id: '404',
        url: '/',
        size: 0,
        ext: constants_1.SupportedExt.jpg,
        originalName: '',
    };
    try {
        await optimize_1.default(image, {
            exportExt: constants_1.SupportedExt.jpg,
        });
    }
    catch (e) {
        expect(e).toBeTruthy();
    }
});
