"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
require("../_tools/before-test");
const path = tslib_1.__importStar(require("path"));
const file_utils_1 = require("../../common/file-utils");
const constants_1 = require("../../common/constants");
const relPath = (file) => path.resolve(__dirname, file);
test('md5', () => {
    expect(file_utils_1.md5('123')).toBe('202cb962ac59075b964b07152d234b70');
});
test('fileMD5', async () => {
    const hash = await file_utils_1.fileMD5(relPath('../_files/600_600.png'));
    expect(hash).toBe('d923e2f3e413a426af54a1535cb6d1ad');
});
test('imageType png', async () => {
    const { ext } = (await file_utils_1.imageType(relPath('../_files/600_600.png')));
    expect(ext).toBe('png');
});
test('imageType jpeg', async () => {
    const { ext } = (await file_utils_1.imageType(relPath('../_files/fox.jpg')));
    expect(ext).toBe('jpg');
});
test('getSize', async () => {
    const size = await file_utils_1.getSize(relPath('../_files/600_600.png'));
    expect(size).toBe(40923);
});
test('getFilePath', async () => {
    const size = await file_utils_1.getFilePath({
        id: 'abcd',
        url: '/',
        size: 0,
        ext: constants_1.SupportedExt.png,
        originalName: '',
    });
    expect(size).toMatch(/\/abcd.png$/);
});
test('saveFilesTmp', async () => {
    const paths = [
        relPath('../_files/600_600.png'),
        relPath('../_files/fox.jpg'),
    ];
    const files = await file_utils_1.saveFilesTmp(paths);
    expect(files[0].ext).toBe('png');
    expect(files[1].ext).toBe('jpg');
});
test('unoccupiedFile 1', async () => {
    const path0 = relPath('../_files/available.png');
    const pathExpect = path0;
    const pathActual = await file_utils_1.unoccupiedFile(path0);
    expect(pathActual).toBe(pathExpect);
});
test('unoccupiedFile 2', async () => {
    const path0 = relPath('../_files/qr.png');
    const pathExpect = relPath('../_files/qr(1).png');
    const pathActual = await file_utils_1.unoccupiedFile(path0);
    expect(pathActual).toBe(pathExpect);
});
test('unoccupiedFile 3', async () => {
    const path0 = relPath('../_files/fox.jpg');
    const pathExpect = relPath('../_files/fox(2).jpg');
    const pathActual = await file_utils_1.unoccupiedFile(path0);
    expect(pathActual).toBe(pathExpect);
});
test('unoccupiedFile 4', async () => {
    const path0 = relPath('../_files/firefox');
    const pathExpect = relPath('../_files/firefox(1)');
    const pathActual = await file_utils_1.unoccupiedFile(path0);
    expect(pathActual).toBe(pathExpect);
});
test('flattenFiles', async () => {
    const sources = [
        '../_files/fox.jpg',
        '../_tools',
    ].map(relPath);
    const output = await file_utils_1.flattenFiles(sources);
    expect(output).toEqual([
        '../_files/fox.jpg',
        '../_tools/before-test.ts',
        '../_tools/image-diff.ts',
    ].map(relPath));
});
test('reext', () => {
    expect(file_utils_1.reext('a/b/c.png', constants_1.SupportedExt.jpg)).toBe('a/b/c.jpg');
    expect(file_utils_1.reext('a/b/c.jpg', constants_1.SupportedExt.webp)).toBe('a/b/c.webp');
    expect(file_utils_1.reext('a/b/c.old', constants_1.SupportedExt.webp)).toBe('a/b/c.old.webp');
    expect(file_utils_1.reext('a/b/c.PNG', constants_1.SupportedExt.png)).toBe('a/b/c.PNG');
});
