"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
require("../_tools/before-test");
const store_1 = require("../../renderer/store/store");
const actionCreaters_1 = tslib_1.__importDefault(require("../../renderer/store/actionCreaters"));
const constants_1 = require("../../common/constants");
const image1 = {
    id: '01',
    url: '01.png',
    size: 100,
    ext: constants_1.SupportedExt.png,
    originalName: 'file.png',
};
const image2 = {
    id: '02',
    url: '02.jpg',
    size: 101,
    ext: constants_1.SupportedExt.jpg,
    originalName: 'file.jpg',
};
test('initial state', () => {
    const store = store_1.createStore();
    expect(store.getState().tasks).toEqual([]);
});
test('task add', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 128,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
        {
            id: image2.id,
            image: image2,
            options: {
                quality: 80,
                exportExt: constants_1.SupportedExt.jpg,
            },
            status: "PENDING" /* PENDING */,
        },
    ]);
});
test('task delete', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    store.dispatch(actionCreaters_1.default.taskDelete([image2.id, 'notexist']));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 128,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
    ]);
});
test('task update options', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    store.dispatch(actionCreaters_1.default.taskUpdateOptions(image2.id, {
        exportExt: constants_1.SupportedExt.jpg,
        color: 8,
    }));
    store.dispatch(actionCreaters_1.default.taskUpdateOptions('notexist', {
        exportExt: constants_1.SupportedExt.jpg,
        color: 8,
    }));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 128,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
        {
            id: image2.id,
            image: image2,
            options: {
                color: 8,
                exportExt: constants_1.SupportedExt.jpg,
            },
            status: "PENDING" /* PENDING */,
        },
    ]);
});
test('task start', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    store.dispatch(actionCreaters_1.default.taskOptimizeStart(image2.id));
    store.dispatch(actionCreaters_1.default.taskOptimizeStart('notexist'));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 128,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
        {
            id: image2.id,
            image: image2,
            options: {
                quality: 80,
                exportExt: constants_1.SupportedExt.jpg,
            },
            status: "PROCESSING" /* PROCESSING */,
        },
    ]);
});
test('task success', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    store.dispatch(actionCreaters_1.default.taskOptimizeSuccess(image2.id, {
        id: '03',
        url: '02.jpg',
        size: 101,
        ext: constants_1.SupportedExt.jpg,
        originalName: 'file-result.jpg',
    }));
    store.dispatch(actionCreaters_1.default.taskOptimizeSuccess('notexist', {}));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 128,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
        {
            id: image2.id,
            image: image2,
            options: {
                quality: 80,
                exportExt: constants_1.SupportedExt.jpg,
            },
            status: "DONE" /* DONE */,
            optimized: {
                id: '03',
                url: '02.jpg',
                size: 101,
                ext: 'jpg',
                originalName: 'file-result.jpg',
            },
        },
    ]);
});
test('task fail', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    store.dispatch(actionCreaters_1.default.taskOptimizeFail(image2.id));
    store.dispatch(actionCreaters_1.default.taskOptimizeFail('notexist'));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 128,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
        {
            id: image2.id,
            image: image2,
            options: {
                quality: 80,
                exportExt: constants_1.SupportedExt.jpg,
            },
            status: "FAIL" /* FAIL */,
        },
    ]);
});
test('globals', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.taskDetail('detailId'));
    expect(store.getState().globals.activeId).toBe('detailId');
    store.dispatch(actionCreaters_1.default.taskDetail(null));
    expect(store.getState().globals.activeId).toBe(null);
});
test('set globalOptions', () => {
    const store = store_1.createStore();
    store.dispatch(actionCreaters_1.default.defaultOptions({
        ext: constants_1.SupportedExt.png,
        options: {
            color: 8,
            exportExt: constants_1.SupportedExt.png,
        },
    }));
    store.dispatch(actionCreaters_1.default.defaultOptions({
        ext: constants_1.SupportedExt.jpg,
        options: {
            quality: 60,
            exportExt: constants_1.SupportedExt.jpg,
        },
    }));
    expect(store.getState().globals.defaultOptions).toEqual({
        png: {
            color: 8,
            exportExt: constants_1.SupportedExt.png,
        },
        jpg: {
            quality: 60,
            exportExt: constants_1.SupportedExt.jpg,
        },
        webp: {
            quality: 80,
            exportExt: constants_1.SupportedExt.webp,
        },
    });
    store.dispatch(actionCreaters_1.default.taskAdd([image1, image2]));
    expect(store.getState().tasks).toEqual([
        {
            id: image1.id,
            image: image1,
            options: {
                color: 8,
                exportExt: constants_1.SupportedExt.png,
            },
            status: "PENDING" /* PENDING */,
        },
        {
            id: image2.id,
            image: image2,
            options: {
                quality: 60,
                exportExt: constants_1.SupportedExt.jpg,
            },
            status: "PENDING" /* PENDING */,
        },
    ]);
});
