"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const events_1 = require("events");
const electron_1 = require("electron");
const menuActions = tslib_1.__importStar(require("./menu-actions"));
const dev_1 = require("./dev");
const locales_1 = tslib_1.__importDefault(require("../locales"));
const package_json_1 = tslib_1.__importDefault(require("../../package.json"));
class MenuManager extends events_1.EventEmitter {
    constructor() {
        super(...arguments);
        this.taskCount = 0;
        this.aloneMode = false;
    }
    handleSave(type) {
        this.emit('save', type);
    }
    render() {
        let saveFragment = [];
        if (this.taskCount) {
            saveFragment = this.aloneMode ? ([{
                    label: locales_1.default('save'),
                    accelerator: 'CommandOrControl+S',
                    click: () => this.handleSave("OVER" /* OVER */),
                },
                {
                    label: locales_1.default('save_as'),
                    click: () => this.handleSave("SAVE_AS" /* SAVE_AS */),
                }]) : ([{
                    label: locales_1.default('save'),
                    accelerator: 'CommandOrControl+S',
                    click: () => this.handleSave("OVER" /* OVER */),
                },
                {
                    label: locales_1.default('save_new'),
                    click: () => this.handleSave("NEW_NAME" /* NEW_NAME */),
                },
                {
                    label: locales_1.default('save_dir'),
                    click: () => this.handleSave("NEW_DIR" /* NEW_DIR */),
                }]);
        }
        const menuTemplates = [
            {
                label: package_json_1.default.name,
                submenu: [
                    {
                        label: locales_1.default('about', package_json_1.default.name),
                        click: menuActions.about,
                    },
                    {
                        type: 'separator',
                    },
                    {
                        role: 'quit',
                    },
                ],
            },
            {
                label: locales_1.default('file'),
                submenu: [
                    {
                        label: locales_1.default('open'),
                        accelerator: 'CommandOrControl+O',
                        click: menuActions.open,
                    },
                    ...saveFragment,
                ],
            },
        ];
        if (dev_1.isDev) {
            menuTemplates.push({
                label: 'Debug',
                submenu: [
                    { role: 'reload' },
                    { role: 'forceReload' },
                    { role: 'toggleDevTools' },
                    { role: 'undo' },
                    { role: 'redo' },
                    { type: 'separator' },
                    { role: 'cut' },
                    { role: 'copy' },
                    { role: 'paste' },
                    { role: 'pasteAndMatchStyle' },
                    { role: 'delete' },
                    { role: 'selectAll' },
                ],
            });
        }
        const menu = electron_1.Menu.buildFromTemplate(menuTemplates);
        electron_1.Menu.setApplicationMenu(menu);
    }
}
exports.default = new MenuManager();
