"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const os = tslib_1.__importStar(require("os"));
const fs = tslib_1.__importStar(require("fs-extra"));
const electron_log_1 = tslib_1.__importDefault(require("electron-log"));
const constants_1 = require("../common/constants");
const fu = tslib_1.__importStar(require("../common/file-utils"));
const optimizers_1 = require("../optimizers/");
const imagemagick_1 = require("./imagemagick");
const platform = os.platform();
const optimize = async (image, options) => {
    let sourcePath = fu.getFilePath(image);
    const optimizedId = fu.md5(image.id + JSON.stringify(options));
    const exportExt = options.exportExt || image.ext;
    const dest = {
        id: optimizedId,
        ext: exportExt,
        originalName: image.originalName,
    };
    const destPath = fu.getFilePath(dest);
    electron_log_1.default.info('optimize', `convert [${image.ext}]${sourcePath} to [${exportExt}]${destPath}`);
    dest.url = 'file://' + destPath;
    try {
        dest.size = await fu.getSize(destPath);
    }
    catch (err) {
        electron_log_1.default.info('optimize', `miss cache (desk)`);
        /**
         * pngquant on linux / windows does not support JPEG to PNG.
         * in this case, we should use ImageMagick converting JPEG to PNG firstly.
         */
        if (platform !== 'darwin' && image.ext === 'jpg' && exportExt === 'png') {
            electron_log_1.default.info('optimize', 'should use ImageMagick for converting JPEG to PNG');
            const intermediate = sourcePath.replace(/\.jpg$/, '.1.png');
            try {
                await fs.access(intermediate);
            }
            catch (err) {
                electron_log_1.default.info('optimize', `miss cache (ImageMagick)`);
                await imagemagick_1.convert(sourcePath, intermediate);
            }
            sourcePath = intermediate;
        }
        const factory = {
            [constants_1.SupportedExt.png]: optimizers_1.pngquant,
            [constants_1.SupportedExt.jpg]: optimizers_1.mozjpeg,
            [constants_1.SupportedExt.webp]: optimizers_1.cwebp,
        };
        const optimizeMethod = factory[exportExt];
        if (!optimizeMethod) {
            throw new Error(`Unsupported file format: ${image.ext}`);
        }
        await optimizeMethod(sourcePath, destPath, options);
        dest.size = await fu.getSize(destPath);
    }
    return dest;
};
exports.default = optimize;
