"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// eg: en-US -> en
const macrolang = (langCode) => langCode.split('-')[0];
function createLocales(locales, macroMap, defaultLang, locale) {
    const macroCode = macrolang(locale);
    const defaultMacro = macroMap && macroMap[macroCode];
    const defaults = locales[defaultLang];
    const macroTexts = locales[macroCode] || locales[defaultMacro] || defaults;
    const texts = locales[locale] || macroTexts;
    if (!defaults)
        throw new Error('Invalid default language');
    /**
     * get text by key
     * @param {string} key
     */
    return function get(key, ...args) {
        let content = texts[key] || macroTexts[key] || defaults[key] || key;
        if (args.length) {
            args.forEach((arg, index) => {
                content = content.replace(new RegExp(`\\{${index}\\}`, 'g'), arg == null ? '' : arg);
            });
        }
        return content;
    };
}
exports.default = createLocales;
