"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const electron_1 = require("electron");
const electron_log_1 = tslib_1.__importDefault(require("electron-log"));
/**
 * make cross process method call easier.
 * the backend side.
 *
 * In main render there is a method whose type is:
 * ```
 * function backendMethod (arg: Arg): Promise<Result> | Result
 * ```
 *
 * We need call it in renderer process, so we should use `electron.rpc`
 * `ipc-bridge` provides a convenient way.
 *
 * usage:
 * ```
 * listenIpc<Arg, Result>(channelName, backendMethod)
 * ```
 *
 * Now we can call the method in renderer side. see renderer.ts for detail.
 *
 * @param channel channel name
 */
exports.listenIpc = (channel, responser) => {
    electron_1.ipcMain.on(channel, async (event, sessionId, data) => {
        let result = null;
        let error = null;
        try {
            result = await responser(data);
        }
        catch (err) {
            electron_log_1.default.error(err);
            error = err;
        }
        event.sender.send(channel, {
            session: sessionId,
            error: error && error.message,
            result,
        });
    });
};
