"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const utils_1 = require("../common/utils");
/**
 * make cross process method call easier.
 * the renderer side.
 *
 * usage:
 * ```
 * const methods = requestCreater<Arg, Result>(channalName)
 * let arg: Arg = {}
 * method(arg).then((result: Result) => {
 *   console.log(result)
 * })
 * ```
 *
 * @param channel channel name
 */
exports.requestCreater = (channel) => (data) => new Promise((resolve, reject) => {
    const sessionId = utils_1.randomId();
    electron_1.ipcRenderer.send(channel, sessionId, data);
    const handler = (event, { error, result, session }) => {
        if (session !== sessionId)
            return;
        if (error) {
            reject(new Error(error));
        }
        else {
            resolve(result);
        }
        electron_1.ipcRenderer.removeListener(channel, handler);
    };
    electron_1.ipcRenderer.on(channel, handler);
});
