"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const child_process_promise_1 = require("child-process-promise");
const electron_log_1 = tslib_1.__importDefault(require("electron-log"));
const bins = tslib_1.__importStar(require("./bin"));
const createEnv = () => {
    return {
        ...process.env,
        LD_LIBRARY_PATH: bins.basePath,
    };
};
exports.mozjpeg = (input, output, options) => {
    const { quality = 70 } = options;
    const spawnArgs = [
        '-quality',
        quality.toString(),
        '-outfile',
        output,
        input,
    ];
    electron_log_1.default.info('spawn', bins.mozjpeg, spawnArgs);
    return child_process_promise_1.spawn(bins.mozjpeg, spawnArgs, {
        capture: ['stdout', 'stderr'],
        env: createEnv(),
    }).catch(e => {
        throw new Error(e.message + '\n' + e.stderr);
    });
};
exports.pngquant = (input, output, options) => {
    const { color = 256 } = options;
    const spawnArgs = [
        color.toString(),
        input,
        '-o',
        output,
    ];
    electron_log_1.default.info('spawn', bins.pngquant, spawnArgs);
    return child_process_promise_1.spawn(bins.pngquant, spawnArgs, {
        capture: ['stdout', 'stderr'],
        env: createEnv(),
    }).catch(e => {
        throw new Error(e.message + '\n' + e.stderr);
    });
};
exports.cwebp = (input, output, options) => {
    const { quality = 80 } = options;
    const spawnArgs = [
        '-q',
        quality.toString(),
        input,
        '-o',
        output,
    ];
    electron_log_1.default.info('spawn', bins.cwebp, spawnArgs);
    return child_process_promise_1.spawn(bins.cwebp, spawnArgs, {
        capture: ['stdout', 'stderr'],
        env: createEnv(),
    }).catch(e => {
        throw new Error(e.message + '\n' + e.stderr);
    });
};
