"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const Popper_1 = tslib_1.__importDefault(require("../components/Popper"));
const Icon_1 = tslib_1.__importDefault(require("./Icon"));
const ImageOptions_1 = tslib_1.__importDefault(require("./ImageOptions"));
const SizeReduce_1 = tslib_1.__importDefault(require("./SizeReduce"));
const TargetTypeSelect_1 = tslib_1.__importDefault(require("./TargetTypeSelect"));
const locales_1 = tslib_1.__importDefault(require("../../locales"));
require("./TaskView.less");
class TaskView extends react_1.PureComponent {
    constructor() {
        super(...arguments);
        this.handleClear = (e) => {
            this.stopEvent(e);
            this.props.onRemove(this.props.task);
        };
        this.handleClick = (e) => {
            if (this.props.task.status === 'FAIL')
                return;
            this.props.onClick(this.props.task);
        };
        this.handleOptionsChange = (options) => {
            this.props.onOptionsChange(this.props.task.id, options);
        };
        this.handleExtChange = (ext) => {
            const { task } = this.props;
            this.props.onExportChange(task.id, ext);
        };
        this.handleSave = (e, type) => {
            this.stopEvent(e);
            this.props.onSave(this.props.task, type);
        };
        this.handleRefreah = (e) => {
            this.stopEvent(e);
            const { task } = this.props;
            this.props.onOptionsChange(task.id, task.options);
        };
        this.stopEvent = (e) => {
            e.preventDefault();
            e.stopPropagation();
        };
    }
    render() {
        const { task, onOptionsChange } = this.props;
        const { image, optimized, options } = task;
        const destImage = task.optimized || task.image;
        const isProcessing = task.status === "PROCESSING" /* PROCESSING */;
        const exportExt = options.exportExt || image.ext;
        return (react_1.default.createElement("div", { className: classnames_1.default('task-view', '-' + task.status) },
            react_1.default.createElement("div", { className: "image-view", onClick: this.handleClick },
                react_1.default.createElement("img", { src: destImage.url, alt: "task-cover" }),
                react_1.default.createElement("div", { className: "image-view-menu" },
                    react_1.default.createElement(Popper_1.default, { hoverMode: true, popper: react_1.default.createElement("div", { className: "popper-body" }, task.status) },
                        react_1.default.createElement("span", { className: "traffic" },
                            react_1.default.createElement(Icon_1.default, { name: isProcessing ? 'color' : 'dot', className: classnames_1.default({
                                    '-spin': isProcessing,
                                }) }))),
                    task.status === "FAIL" /* FAIL */ ? (react_1.default.createElement("a", { href: "#", onClick: this.handleRefreah },
                        react_1.default.createElement(Icon_1.default, { name: "refresh" }))) : null,
                    react_1.default.createElement(Popper_1.default, { hoverMode: true, popper: (react_1.default.createElement("div", { className: "popper-menu" },
                            react_1.default.createElement("a", { href: "#", onClick: e => this.handleSave(e, "OVER" /* OVER */) }, locales_1.default('save')),
                            react_1.default.createElement("a", { href: "#", onClick: e => this.handleSave(e, "SAVE_AS" /* SAVE_AS */) }, locales_1.default('save_as')))) },
                        react_1.default.createElement("a", { href: "#", onClick: this.stopEvent },
                            react_1.default.createElement(Icon_1.default, { name: "down" }))),
                    react_1.default.createElement("span", { className: "blank" }),
                    react_1.default.createElement("a", { className: "close", href: "#", onClick: this.handleClear },
                        react_1.default.createElement(Icon_1.default, { name: "clear" })))),
            react_1.default.createElement("div", { className: "image-profile" },
                react_1.default.createElement(ImageOptions_1.default, { ext: exportExt, options: options, precision: false, onChange: this.handleOptionsChange }),
                react_1.default.createElement("div", null,
                    react_1.default.createElement("div", { className: "image-sizes" },
                        react_1.default.createElement(TargetTypeSelect_1.default, { sourceExt: image.ext, targetExt: exportExt, onChange: this.handleExtChange }),
                        react_1.default.createElement(SizeReduce_1.default, { task: task }))))));
    }
}
exports.default = TaskView;
