"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_redux_1 = require("react-redux");
const ImageOptions_1 = tslib_1.__importDefault(require("../components/ImageOptions"));
const ImageViewer_1 = tslib_1.__importDefault(require("../components/ImageViewer"));
const Modal_1 = tslib_1.__importDefault(require("../components/Modal"));
const Icon_1 = tslib_1.__importDefault(require("../components/Icon"));
const SizeReduce_1 = tslib_1.__importDefault(require("../components/SizeReduce"));
const RadioGroup_1 = tslib_1.__importDefault(require("../components/RadioGroup"));
const TargetTypeSelect_1 = tslib_1.__importDefault(require("../components/TargetTypeSelect"));
const actionCreaters_1 = tslib_1.__importDefault(require("../store/actionCreaters"));
const selectors_1 = require("../store/selectors");
const locales_1 = tslib_1.__importDefault(require("../../locales"));
require("./Alone.less");
const imageStageList = ["before_optimized" /* beforeOptimized */, "after_optimized" /* afterOptimized */];
class Alone extends react_1.PureComponent {
    constructor(props) {
        super(props);
        this.handleOptionsChange = (options) => {
            this.props.onOptionsChange(this.props.task.id, options);
        };
        this.handleKeyPress = (e) => {
            if (e.keyCode === 27) {
                this.props.onClose();
            }
        };
        this.handleImageStageChange = (value) => {
            this.setState({
                imageStage: value,
            });
        };
        this.handleExtChange = (ext) => {
            const task = this.props.task;
            this.props.onExportChange(task.id, ext);
        };
        this.state = {
            imageStage: "after_optimized" /* afterOptimized */,
        };
    }
    componentDidMount() {
        window.addEventListener('keyup', this.handleKeyPress);
    }
    componentWillUnmount() {
        window.removeEventListener('keyup', this.handleKeyPress);
    }
    renderControllers() {
        const task = this.props.task;
        const { image, optimized, options, status } = task;
        const exportExt = options.exportExt || image.ext;
        return (react_1.default.createElement("div", null,
            status === "PROCESSING" /* PROCESSING */ || status === "PENDING" /* PENDING */
                ? react_1.default.createElement(Icon_1.default, { className: "-spin", name: "color" })
                : null,
            react_1.default.createElement(SizeReduce_1.default, { task: task }),
            react_1.default.createElement("div", { className: "paper alone-options" },
                react_1.default.createElement(TargetTypeSelect_1.default, { sourceExt: image.ext, targetExt: exportExt, onChange: this.handleExtChange }),
                react_1.default.createElement(ImageOptions_1.default, { ext: exportExt, options: options, precision: true, onChange: this.handleOptionsChange })),
            react_1.default.createElement(RadioGroup_1.default, { className: "original-check -standard", data: imageStageList, value: this.state.imageStage, renderItem: locales_1.default, onChange: this.handleImageStageChange })));
    }
    render() {
        const { task } = this.props;
        const { imageStage } = this.state;
        /**
         * image that show in imageViewew
         */
        let image;
        if (task) {
            image = imageStage === "after_optimized" /* afterOptimized */
                ? task.optimized
                : task.image;
        }
        return (react_1.default.createElement(Modal_1.default, { className: "alone-modal", visible: !!task, onClose: this.props.onClose },
            react_1.default.createElement(ImageViewer_1.default, { src: image && image.url }),
            task && this.renderControllers()));
    }
}
exports.default = react_redux_1.connect(state => ({
    task: selectors_1.getActiveTask(state),
}), dispatch => ({
    onClose() {
        dispatch(actionCreaters_1.default.taskDetail(null));
    },
    onOptionsChange(id, options) {
        dispatch(actionCreaters_1.default.taskUpdateOptions(id, options));
    },
    onExportChange(id, ext) {
        dispatch(actionCreaters_1.default.taskUpdateExport(id, ext));
    },
}))(Alone);
