"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const apis_1 = require("../apis/");
const actionCreaters_1 = tslib_1.__importDefault(require("../store/actionCreaters"));
const lodash_1 = require("lodash");
const electron_log_1 = tslib_1.__importDefault(require("electron-log"));
class Daemon {
    constructor() {
        this.running = false;
        this.trigger = lodash_1.debounce(() => {
            if (this.running)
                return;
            this.start();
        }, 100);
    }
    watch(store) {
        this.store = store;
        store.subscribe(() => this.trigger());
    }
    pickPendingTask() {
        const state = this.store.getState();
        return state.tasks.find(task => task.status === "PENDING" /* PENDING */);
    }
    async start() {
        this.running = true;
        const store = this.store;
        while (true) {
            const task = this.pickPendingTask();
            if (!task)
                break;
            try {
                store.dispatch(actionCreaters_1.default.taskOptimizeStart(task.id));
                const optimized = await apis_1.optimize(task);
                store.dispatch(actionCreaters_1.default.taskOptimizeSuccess(task.id, optimized));
            }
            catch (err) {
                electron_log_1.default.error(err);
                store.dispatch(actionCreaters_1.default.taskOptimizeFail(task.id));
            }
        }
        this.running = false;
    }
}
exports.default = Daemon;
