"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const webpack_1 = tslib_1.__importDefault(require("webpack"));
const html_webpack_plugin_1 = tslib_1.__importDefault(require("html-webpack-plugin"));
const plugin_1 = tslib_1.__importDefault(require("svg-sprite-loader/plugin"));
const rel = (filename) => path_1.default.resolve(__dirname, filename);
const NODE_ENV = process.env.NODE_ENV;
exports.default = (env, argv) => {
    const isDev = argv.mode === 'development';
    const addHotEntry = (entry) => {
        if (isDev) {
            return [
                'react-hot-loader/patch',
                `webpack-dev-server/client?http://localhost:9999/`,
                'webpack/hot/only-dev-server',
            ].concat(entry);
        }
        else {
            return entry;
        }
    };
    const entries = {
        app: addHotEntry('./modules/renderer/Index'),
    };
    const config = {
        mode: argv.mode,
        entry: entries,
        output: {
            path: rel('../htdocs'),
            filename: '[name].js',
        },
        module: {
            rules: [
                {
                    test: /\.tsx?$/,
                    use: [
                        {
                            loader: 'babel-loader',
                        },
                        {
                            loader: 'ts-loader',
                            options: {
                                compilerOptions: {
                                    module: 'es2015',
                                },
                            },
                        },
                    ],
                },
                {
                    test: /\.less$/,
                    use: [
                        'style-loader',
                        'css-loader',
                        'less-loader',
                    ],
                },
                {
                    test: /\.(png|jpg)$/,
                    use: [
                        {
                            loader: 'file-loader',
                            options: {
                                name: 'res/[name]-[hash:6].[ext]',
                            },
                        },
                    ],
                },
                {
                    test: /\.svg$/,
                    use: [
                        {
                            loader: 'svg-sprite-loader',
                            options: {
                                symbolId: 'icon-[name]',
                            },
                        },
                    ],
                },
            ],
        },
        plugins: [
            new webpack_1.default.HotModuleReplacementPlugin(),
            new webpack_1.default.DefinePlugin({
                'process.env': {
                    NODE_ENV: JSON.stringify(NODE_ENV),
                },
            }),
            new plugin_1.default(),
            ...Object.keys(entries)
                .map(entry => new html_webpack_plugin_1.default({
                filename: entry + '.html',
                template: 'modules/renderer/template.html',
            })),
        ],
        resolve: {
            extensions: ['.js', '.ts', '.json', '.tsx'],
            alias: {},
        },
        target: 'electron-renderer',
        devServer: {},
    };
    return config;
};
